@@ -20,9 +20,9 @@
 #ifndef __ASM_ARM_ARCH_IO_H
 #define __ASM_ARM_ARCH_IO_H
 
-#define IO_SPACE_LIMIT 0xffff
+#define IO_SPACE_LIMIT 0xffffffff
 
-#define __io(a)				((unsigned long) IO_ADDRESS(a))
+#define __io(a)			((unsigned long)(a))
 #define __mem_pci(a)		((unsigned long)(a))
 #define __mem_isa(a)		((unsigned long)(a))
 
@@ -38,8 +38,23 @@
 #define iomem_valid_addr(iomem,size)	(1)
 
 /*
- * Convert PCI memory space to a CPU physical address
+ * Convert PCI memory space to a CPU physical address.  This is only used
+ * by ioremap().  We will feed ioremap with yummy physical addresses and
+ * it will do its magical mystical thing and remap them to some random
+ * virtual address that it will give us.
  */
-#define iomem_to_phys(iomem)	IO_ADDRESS(iomem)
+#define iomem_to_phys(iomem)	(iomem)
+
+/*
+ * These routines are used to hack the default ide i/o routines in
+ * drivers/ide/ide-iops.h so they work with PCMCIA IDE.  Sad, but
+ * necessary.	They are fleshed out in arch/arm/mach-ep93xx/pcmcia_io.c.
+ */
+inline u8 ep93xx_pcmcia_ide_inb (unsigned long port);
+inline u16 ep93xx_pcmcia_ide_inw (unsigned long port);
+inline void ep93xx_pcmcia_ide_insw (unsigned long port, void *addr, u32 count);
+inline void ep93xx_pcmcia_ide_outb (u8 addr, unsigned long port);
+inline void ep93xx_pcmcia_ide_outw (u16 addr, unsigned long port);
+inline void ep93xx_pcmcia_ide_outsw (unsigned long port, void *addr, u32 count);
 
 #endif
