@@ -1,6 +1,6 @@
 /*****************************************************************************
-*	$Author: gerg $
-*	$Revision: 1.1 $
+*	$Author: Richarjc $
+*	$Revision: 5 $
 *	$Modtime: 6/03/02 8:38a $
 ****************************************************************************/
 
